@@ -1,5 +1,5 @@
 <?php
-/* unsafe_image_rules -- Version 0.2
+/* unsafe_image_rules -- Version 0.3
  * By Robin Rainton <robin@rainton.com>
  * http://rainton.com/fun/freeware
  *
@@ -12,28 +12,49 @@
   require_once('../functions/page_header.php');
   require_once('../src/load_prefs.php');
 
+/*
+ * Get globals
+ */
+
+  $username = $_SESSION['username'];
+
+/*
+ * Start options page display.
+ */
+
   displayPageHeader($color, 'None');
 
-  if (isset($unsafe_image_rules_submit)) {
-     if (!isset($theid)) $theid = 0;
+/*
+ * Get variables from our form that are frequently used.
+ */
+
+  $action = $_GET['action'];
+  $theid = $_GET['theid'];
+  $how = $_POST['how'];
+  $where = $_POST['where'];
+  $what = $_POST['what'];
+
+  if (isset($_POST['unsafe_image_rules_submit'])) {
+     $theid = isset($_POST['theid'])? $_POST['theid'] : $theid = 0;
 /*
  * This is a bit bad, but if $how is regexp then prefix
  * $where with "R". This makes stuff backwards compatable.
  */
+
      if ($how == 'regexp') $where = "R" . $where;
 
      setPref($data_dir, $username, "unsafe_image_rules".$theid, $where.",".$what);
   } elseif (isset($action) && $action == 'delete') {
      remove_trusted($theid);
-  } elseif (isset($user_submit)) {
+  } elseif (isset($_POST['user_submit'])) {
       setPref($data_dir, $username, 'unsafe_image_rules_all',
-              isset($uir_all) ? "1" : "0");
+              isset($_POST['uir_all']) ? "1" : "0");
       setPref($data_dir, $username, 'unsafe_image_rules_addr',
-              isset($uir_addr) ? "1" : "0");
+              isset($_POST['uir_addr']) ? "1" : "0");
       setPref($data_dir, $username, 'unsafe_image_rules_ids',
-              isset($uir_ids) ? "1" : "0");
+              isset($_POST['uir_ids']) ? "1" : "0");
       setPref($data_dir, $username, 'unsafe_image_rules_trusted',
-              isset($uir_trusted) ? "1" : "0");
+              isset($_POST['uir_trusted']) ? "1" : "0");
       echo "<br><center><b>"._("Saved Trusted Options")."</b></center>\n";
   }
 
