@@ -1,5 +1,5 @@
 <?php
-/* unsafe_image_rules -- Version 0.2
+/* unsafe_image_rules -- Version 0.3
  * By Robin Rainton <robin@rainton.com>
  * http://rainton.com/fun/freeware
  *
@@ -8,6 +8,8 @@
  * message each time.
  */
 
+require_once("../functions/addressbook.php"); 
+
 /*
  * Adminstrator options.
  * Set unsafe_image_rules_disable_all to non-zero to prevent this option
@@ -24,7 +26,6 @@ $unsafe_image_rules_disable_all = 0;
 
 function squirrelmail_plugin_init_unsafe_image_rules() {
   global $squirrelmail_plugin_hooks;
-#  $squirrelmail_plugin_hooks['read_body_header']['unsafe_image_rules'] =
   $squirrelmail_plugin_hooks['message_body']['unsafe_image_rules'] =
     'unsafe_image_rules_main';
   $squirrelmail_plugin_hooks['optpage_register_block']['unsafe_image_rules'] =
@@ -76,7 +77,7 @@ function unsafe_image_rules_main()
   */
 
   $unsafe_image_rules_addr = getPref($data_dir, $username,
-                                        'unsafe_image_rules_addr');
+                                     'unsafe_image_rules_addr');
   if (isset($unsafe_image_rules_addr) && $unsafe_image_rules_addr &&
       is_from_sender_in_address_book($message))
   {
